
#####load packages and set wd####
library("tidyverse")
library("ggplot2")
library("viridis")
library("Rmisc")
library("lme4")

#####ICC analysis####
data <-read.csv("TRUESPERM.csv")


fas <- data
fast <- fas %>% select(tuttreatment, Tuatara, Treatment, VCL) #here selecting just the site, tut/treatment and the VCL
fast <- fast %>% arrange(tuttreatment, desc(VCL)) #Arranging from fastest to slowest VCL for each tut/treatment
fas <- fast %>% group_by(tuttreatment) #Groups each tut/treatment's sperm together as a group
count.sperm <- as.data.frame(fas %>% count(tuttreatment, wt=NULL))  

fas5 <- fas %>% top_n(n=5, wt=VCL)
fas10 <- fas %>% top_n(n=10, wt=VCL)
fas20 <- fas %>% top_n(n=20, wt=VCL)
fas50 <- fas %>% top_n(n=50, wt=VCL)
fas100 <- fas %>% top_n(n=100, wt=VCL)

#Co-erce each object into a data frame

fas5 <-as.data.frame(fas5)
fas10 <-as.data.frame(fas10)
fas20 <-as.data.frame(fas20)
fas50 <-as.data.frame(fas50)
fas100 <-as.data.frame(fas100)
c.VCL <- scale(fas5$VCL, scale=T)
fas5[,"c.VCL"]<-c.VCL
rep.fas5 <- lmer(c.VCL ~ 1 + (1|tuttreatment), data=fas5)
c.VCL <- scale(fas10$VCL, scale=T)
fas10[,"c.VCL"]<-c.VCL
rep.fas10 <- lmer(c.VCL ~ 1 + (1|tuttreatment), data=fas10)
c.VCL <- scale(fas20$VCL, scale=T)
fas20[,"c.VCL"]<-c.VCL
rep.fas20 <- lmer(c.VCL ~ 1 + (1|tuttreatment), data=fas20)
c.VCL <- scale(fas50$VCL, scale=T)
fas50[,"c.VCL"]<-c.VCL
rep.fas50 <- lmer(c.VCL ~ 1 + (1|tuttreatment), data=fas50)
c.VCL <- scale(fas100$VCL, scale=T)
fas100[,"c.VCL"]<-c.VCL
rep.fas100 <- lmer(c.VCL ~ 1 + (1|tuttreatment), data=fas100)



#Now using lmer function VarCorr to extract variance and correlation components. attr = get attributes

#Get within group variance (sperm.var) and between group variance (male.var)

sperm.var <- c(attr(VarCorr(rep.fas5),"sc")^2, attr(VarCorr(rep.fas10),"sc")^2, attr(VarCorr(rep.fas20),"sc")^2, attr(VarCorr(rep.fas50),"sc")^2, attr(VarCorr(rep.fas100), "sc")^2)
sperm.var
male.var <- c(attr(VarCorr(rep.fas5)$tuttreatment,"stddev")^2, attr(VarCorr(rep.fas10)$tuttreatment,"stddev")^2, attr(VarCorr(rep.fas20)$tuttreatment,"stddev")^2, attr(VarCorr(rep.fas50)$tuttreatment,"stddev")^2, attr(VarCorr(rep.fas100)$tuttreatment, "stddev")^2)
male.var

#Set groups for how many sperm we want to look at 
group <- c(5,10,20,50,100)

#Calculation of ICC (or releatability - = between group variance/(between group variance + within group variance))
rep <- male.var/(male.var+sperm.var)
rep

#Make data frame containing all the variance and ICC numbers
allvarrep <- data.frame(group, male.var, sperm.var, rep)
allvarrep

#now get everything together to make a plot of this info
group.1 <- c(5,10,20,50,100,5,10,20,50,100,5,10,20,50,100)

#Create values object to base y-scale on
values <- c(attr(VarCorr(rep.fas5),"sc")^2, attr(VarCorr(rep.fas10),"sc")^2, attr(VarCorr(rep.fas20),"sc")^2, attr(VarCorr(rep.fas50),"sc")^2, attr(VarCorr(rep.fas100), "sc")^2, attr(VarCorr(rep.fas5)$tuttreatment,"stddev")^2, attr(VarCorr(rep.fas10)$tuttreatment,"stddev")^2, attr(VarCorr(rep.fas20)$tuttreatment,"stddev")^2, attr(VarCorr(rep.fas50)$tuttreatment,"stddev")^2, attr(VarCorr(rep.fas100)$tuttreatment, "stddev")^2, allvarrep$rep[1], allvarrep$rep[2], allvarrep$rep[3], allvarrep$rep[4], allvarrep$rep[5])
values
variable <- c("Within male variance", "Within male variance", "Within male variance","Within male variance", "Within male variance", "Between male variance", "Between male variance", "Between male variance", "Between male variance", "Between male variance", "ICC", "ICC", "ICC", "ICC", "ICC")


#Make object that has all data needed for graph plot
plot.allvarrep <- data.frame(group.1,values, variable)

plot.allvarrep$variable <- factor(plot.allvarrep$variable, levels=c("Between male variance", "Within male variance", "ICC"))

plot.allvarrep

#####Make ICC plot using ggplot2####

ICCplot <- ggplot(plot.allvarrep, aes(x=group.1, y=values, color= variable))+
                    geom_point(size=2, alpha=0.8)+geom_smooth(span=1, size=0.5, se=FALSE)+theme_bw()+theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+ylim(0,1)+ 
  theme(legend.position='right')+
  ylab("")+xlab("Fastest sperm (cumulative)")+
  theme(plot.title = element_text(size = 10, face = "bold")) +
  geom_vline(xintercept = 5, colour="black", size=0.1)+
  geom_vline(xintercept = 10, colour="black", size=0.1)+
  geom_vline(xintercept = 20, colour="black", size=0.1)+
  geom_vline(xintercept = 50, colour="black", size=0.1)+
  geom_vline(xintercept = 100, colour="black", size=0.1) + 
  scale_x_continuous(breaks=c(0,5,10,20,50,100))+theme(legend.position=c(.80, .80), legend.title=element_blank(), legend.key = element_blank())+ylab("Proportion of variance and ICC") +
  scale_color_manual(values=c('#440154FF','#73D055FF', '#00CED1')) +
  theme(axis.text.x = element_text(size=12)) +
  theme(axis.text.y = element_text(size=12)) +
  theme(axis.title.x = element_text(size=12)) +
  theme(axis.title.y = element_text(size=12)) +
  theme(legend.text=element_text(size=10))

ICCplot


####diluents for  males 102,103, and 113 without added time####
write.csv(fas5, file = "fas5.csv", row.names = F)
data<-read.csv("fas5.csv")

plot4b1<-subset(data, Tuatara %in% c("103", "113", "102"))
plot4b1data<-subset(plot4b1, Treatment %in% c("DMEM", "MEM", "MEM + G", "PBS", "PBS + G"))
plot4b1data

plot4b1data<-summarySE(data = plot4b1data, measurevar = "VCL", groupvars = c("Tuatara", "Treatment"))

ggplot(plot4b1data, aes(x = (as.character(Tuatara)), y = VCL, fill = Treatment)) +
  geom_bar(stat = "identity", position = position_dodge2(preserve = 'single'), width =0.9) + 
  labs (x= "Individual", y = "Curvilinear Velocty (m  s???1)") +theme_bw() +
  geom_errorbar(aes(ymin=VCL-ci, ymax=VCL+ci), width=.9,
                position=position_dodge2(preserve='single')) +
  theme(legend.text=element_text(size=8)) +
  theme(legend.title = element_text(size=8)) +
  theme(legend.position = "right")

####making fig 4c, effect of time on diluents####

data <-read.csv("timeeffects.csv")
datase<-summarySE(data = data, measurevar = "VCL", groupvars = c("Tuatara", "Treatment"))

ggplot(datase, aes(x = (as.character(Tuatara)), y = VCL, fill = Treatment)) +
  geom_bar(stat = "identity", position = position_dodge2(preserve = 'single'), width =0.9) + 
  labs (x= "Individual", y = "Curvilinear Velocty (m  s???1)") +theme_bw() +
  geom_errorbar(aes(ymin=VCL-ci, ymax=VCL+ci), width=.9,
                position=position_dodge2(preserve='single')) +
  theme(legend.text=element_text(size=8)) +
  theme(legend.title = element_text(size=8)) +
  theme(legend.position = "right")
